@@ -1,6 +1,5 @@
 /*
- * Copyright (c) 2005-2011 Alon Bar-Lev <alon.barlev@gmail.com>
- * All rights reserved.
+ * Copyright (c) 2005-2018 Alon Bar-Lev <alon.barlev@gmail.com>
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -109,8 +108,10 @@ extern "C" {
 #define PKCS11H_FEATURE_MASK_SLOTEVENT			(1<< 8)
 /** OpenSSL interface is enabled. */
 #define PKCS11H_FEATURE_MASK_OPENSSL			(1<< 9)
-/** Engine PolarSSL is enabled. */
+/** Engine mbed TLS is enabled. */
 #define PKCS11H_FEATURE_MASK_ENGINE_CRYPTO_POLARSSL	(1<< 10)
+/** Engine mbed TLS is enabled. */
+#define PKCS11H_FEATURE_MASK_ENGINE_CRYPTO_MBEDTLS	(1<< 10)
 /** @} */
 
 /**
@@ -340,7 +341,7 @@ pkcs11h_getLogLevel (void);
  * @return CK_RV.
  * @attention
  * This function should be called after @ref pkcs11h_initialize()
- * @note 
+ * @note
  * This funciton is releavant if @ref PKCS11H_FEATURE_MASK_THREADING is set.
  * If safe mode is on, the child process can use the loaded PKCS#11 providers
  * but it cannot use fork(), while it is in one of the hooks functions, since
@@ -479,7 +480,11 @@ pkcs11h_removeProvider (
 /**
  * @brief Handle special case of POSIX fork()
  * @return CK_RV.
- * @attention This function must be called from the main thread.
+ * @attention
+ * This function must be called once from the main thread of child process.
+ * It must be called before any pkcs11-helper calls.
+ * In case you do not want to use PKCS#11 at child, call this function and
+ * then pkcs11h_terminate.
  * @attention
  * This function should be called after fork is called. This is required
  * due to a limitation of the PKCS#11 standard.
@@ -504,7 +509,7 @@ pkcs11h_forkFixup (void);
 CK_RV
 pkcs11h_plugAndPlay (void);
 
-/** 
+/**
  * @brief Logout from all sessions.
  * @return CK_RV.
  */
