@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2011 Alon Bar-Lev <alon.barlev@gmail.com>
+ * Copyright (c) 2005-2018 Alon Bar-Lev <alon.barlev@gmail.com>
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -263,6 +263,7 @@ DSA_SIG_set0 (DSA_SIG *sig, BIGNUM *r, BIGNUM *s)
 }
 #endif
 
+#ifdef __ENABLE_EC
 #ifndef HAVE_ECDSA_SIG_SET0
 static int
 ECDSA_SIG_set0 (ECDSA_SIG *sig, BIGNUM *r, BIGNUM *s)
@@ -275,7 +276,6 @@ ECDSA_SIG_set0 (ECDSA_SIG *sig, BIGNUM *r, BIGNUM *s)
 }
 #endif
 
-#ifdef __ENABLE_EC
 #ifndef HAVE_EC_KEY_METHOD_GET_SIGN
 void EC_KEY_METHOD_get_sign(const EC_KEY_METHOD *meth,
 	int (**psign)(int type, const unsigned char *dgst,
@@ -478,6 +478,9 @@ __pkcs11h_openssl_rsa_dec (
 			rv = CKR_MECHANISM_INVALID;
 		break;
 		case RSA_NO_PADDING:
+			mech = CKM_RSA_X_509;
+		break;
+		default:
 			rv = CKR_MECHANISM_INVALID;
 		break;
 	}
@@ -552,6 +555,7 @@ __pkcs11h_openssl_rsa_enc (
 	PKCS11H_BOOL session_locked = FALSE;
 	CK_RV rv = CKR_FUNCTION_FAILED;
 	size_t tlen;
+	CK_MECHANISM_TYPE mech = CKM_RSA_PKCS;
 
 	_PKCS11H_ASSERT (from!=NULL);
 	_PKCS11H_ASSERT (to!=NULL);
@@ -567,9 +571,16 @@ __pkcs11h_openssl_rsa_enc (
 		padding
 	);
 
-	if (padding != RSA_PKCS1_PADDING) {
-		rv = CKR_MECHANISM_INVALID;
-		goto cleanup;
+	switch (padding) {
+		case RSA_PKCS1_PADDING:
+			mech = CKM_RSA_PKCS;
+		break;
+		case RSA_NO_PADDING:
+			mech = CKM_RSA_X_509;
+		break;
+		default:
+			rv = CKR_MECHANISM_INVALID;
+			goto cleanup;
 	}
 
 	tlen = (size_t)RSA_size(rsa);
@@ -587,7 +598,7 @@ __pkcs11h_openssl_rsa_enc (
 	if (
 		(rv = pkcs11h_certificate_signAny (
 			certificate,
-			CKM_RSA_PKCS,
+			mech,
 			from,
 			flen,
 			to,
